/* eslint-disable no-console */
import { Category, CategoryConfiguration, CategoryLogFormat, CategoryServiceFactory, LoggerType, LogLevel, } from 'typescript-logging';
import { Guid } from 'guid-typescript';
import CustomLogger from './customLogger';
var ItpLogLevel;
(function (ItpLogLevel) {
    ItpLogLevel[ItpLogLevel["Trace"] = 0] = "Trace";
    ItpLogLevel[ItpLogLevel["Debug"] = 1] = "Debug";
    ItpLogLevel[ItpLogLevel["Info"] = 2] = "Info";
    ItpLogLevel[ItpLogLevel["Warn"] = 3] = "Warn";
    ItpLogLevel[ItpLogLevel["Error"] = 4] = "Error";
    ItpLogLevel[ItpLogLevel["Fatal"] = 5] = "Fatal";
})(ItpLogLevel || (ItpLogLevel = {}));
class log {
    constructor(component) {
        const componentName = `${log.rootCategory.name}:${component}(${log.currentIterationId})`;
        this.category = new Category(componentName, log.rootCategory);
    }
    static init() {
        //log.customConfig is using for our custom logger, if you want to change to the default logger (console) -
        // in the following two lines, replace log.customConfig with log.defaultConfig
        CategoryServiceFactory.setConfigurationCategory(log.defaultConfig, log.rootCategory, true);
        CategoryServiceFactory.setDefaultConfiguration(log.customConfig);
        const logMethod = console.log;
        console.log = function () {
            // 1. Convert args to a normal array
            // eslint-disable-next-line prefer-rest-params
            const args = Array.prototype.slice.call(arguments);
            // 2. Prepend log prefix log string
            args.unshift(`${log.rootCategory.name}:console(${log.currentIterationId}):`);
            // 3. Pass along arguments to console.log
            logMethod.apply(console, args);
        };
    }
    trace(message) {
        return this.category.trace(() => message);
    }
    debug(message) {
        return this.category.debug(() => message);
    }
    info(message) {
        return this.category.info(() => message);
    }
    warn(message) {
        return this.category.warn(() => message);
    }
    error(message, error) {
        return this.category.error(() => message, () => (!error ? null : error));
    }
    fatal(message, error) {
        return this.category.fatal(() => message, () => (!error ? null : error));
    }
    getLogLevel() {
        return this.category.logLevel.valueOf();
    }
}
log.rootCategory = new Category(`API sdk`);
log.currentIterationId = Guid.create()
    .toString()
    .substr(24);
log.defaultConfig = new CategoryConfiguration(process.env.NODE_ENV === 'production' ? LogLevel.Info : LogLevel.Trace, LoggerType.Console, new CategoryLogFormat(undefined, false));
log.customConfig = new CategoryConfiguration(LogLevel.Info, LoggerType.Custom, new CategoryLogFormat(), (category, runtimeSettings) => new CustomLogger(category, runtimeSettings));
log.init();
export default function getLogger(componentName) {
    return new log(componentName);
}
//# sourceMappingURL=log.js.map